@@ -1,5 +1,6 @@
 import copy
 import hashlib
+import numbers
 import warnings
 
 import lmfit
@@ -14,9 +15,10 @@ FP_DEFAULT = dict(model_key="hertz_para",
                   optimal_fit_num_samples=100,
                   params_initial=None,
                   preprocessing=[],
+                  preprocessing_options={},
                   range_type="absolute",
                   range_x=[0, 0],
-                  segment="approach",
+                  segment=0,
                   weight_cp=1e-6,
                   x_axis="tip position",
                   y_axis="force",
@@ -60,24 +62,17 @@ class FitProperties(dict):
       obsolete fitting results).
 
     Additional attributes:
-
-    - "segment_bool": bool
-        `False` for "approach" and `True` for "retract"
     """
-
-    def __getitem__(self, key):
-        if key == "segment_bool":
-            if self["segment"] == "approach":
-                return False
-            if self["segment"] == "retract":
-                return True
-            else:
-                msg = "Unknown segment: {}".format(self["segment"])
-                raise FitKeyError(msg)
-        else:
-            return super(FitProperties, self).__getitem__(key)
-
     def __setitem__(self, key, value):
+        if key == "segment":
+            # Since version 1.8.0, nanite uses an integer to identify
+            # the segment. Replace the input accordingly for backwards
+            # compatibility.
+            if value == "approach":
+                value = 0
+            elif value == "retract":
+                value = 1
+        # Proceed with normal checks.
         if key in FP_DEFAULT:
             if (key in self
                 and key == "params_initial"
@@ -151,9 +146,11 @@ class IndentationFitter(object):
                 point. Since the contact point is a fit parameter
                 as well, this requires a two-pass fitting.
         preprocessing: list of str
-            Preprocessing
-        segment: str
-            One of "approach" or "retract".
+            Preprocessing step identifiers
+        preprocessing_options: dict of dicts
+            Preprocessing keyword arguments of steps (if applicable)
+        segment: int
+            Segment index (e.g. 0 for approach)
         weight_cp: float
             Weight the contact point region which shows artifacts
             that are difficult to model with e.g. Hertz.
@@ -191,7 +188,7 @@ class IndentationFitter(object):
             )
 
         # Set arrays
-        self.segment = (idnt["segment"] == self.fp["segment_bool"])
+        self.segment = idnt["segment"] == self.fp["segment"]
         self.segment.setflags(write=False)
 
         self.x_axis = idnt[self.fp["x_axis"]]
@@ -223,9 +220,9 @@ class IndentationFitter(object):
         if (np.isnan(self.fp["range_x"][0]) or
                 np.isnan(self.fp["range_x"][1])):
             raise FitKeyError("`range_x` must not contain NaN!")
-        if self.fp["segment"] not in ["approach", "retract"]:
-            msg = "`segment` must be  'approach' or 'retract'!"
-            raise FitKeyError(msg)
+        if not isinstance(self.fp["segment"], numbers.Integral):
+            raise FitKeyError(
+                f"`segment` must be integer, got '{self.fp['segment']}!")
         if self.fp["model_key"] not in model.models_available:
             msg = "unknown model '{}'".format(self.fp["model_key"])
             raise FitKeyError(msg)
@@ -268,14 +265,14 @@ class IndentationFitter(object):
         # We are agnostic concerning the direction of indentation.
         # `xseg` should start at the baseline.
         seems_approach = np.average(yseg[:10]) < np.average(yseg[-10:])
-        if seems_approach and self.fp["segment"] == "approach":
+        if seems_approach and self.fp["segment"] == 0:
             if xseg[0] < xseg[-1]:
                 msg = "Unexpected trend in approach x data!"
                 raise FitDataError(msg)
         elif seems_approach:
             msg = "Data appears to be 'approach', but is 'retract'!"
             raise FitDataError(msg)
-        elif not seems_approach and self.fp["segment"] == "retract":
+        elif not seems_approach and self.fp["segment"] > 0:
             if xseg[0] > xseg[-1]:
                 msg = "Unexpected trend in retract x data!"
                 raise FitDataError(msg)
@@ -503,6 +500,7 @@ class IndentationFitter(object):
         hashlist = []
         # preprocessing
         hashlist.append(self.fp["preprocessing"])
+        hashlist.append(self.fp["preprocessing_options"])
         # axes data
         hashlist.append(self.x_axis)
         hashlist.append(self.y_axis)
@@ -572,7 +570,7 @@ def obj2bytes(obj):
     """Bytes representation of an object for hashing"""
     if isinstance(obj, str):
         return obj.encode("utf-8")
-    elif isinstance(obj, (bool, int, float)):
+    elif isinstance(obj, (bool, int, float, np.bool_)):
         return str(float(obj)).encode("utf-8")
     elif obj is None:
         return b"none"
@@ -583,7 +581,7 @@ def obj2bytes(obj):
     elif isinstance(obj, list):
         return b"".join(obj2bytes(o) for o in obj)
     elif isinstance(obj, dict):
-        return obj2bytes(list(obj.items()))
+        return obj2bytes(sorted(obj.items()))
     elif isinstance(obj, lmfit.parameter.Parameter):
         return obj2bytes([obj.value, obj.max, obj.min, obj.vary,
                           obj.expr, obj.name])
