@@ -1,36 +1,32 @@
 from collections import OrderedDict
 import copy
 import inspect
+import warnings
 
-import lmfit
+import afmformats
 import numpy as np
-import scipy.signal as spsig
 
 from .fit import IndentationFitter, FitProperties, guess_initial_parameters, \
     FP_DEFAULT
 from . import model
+from . import poc
 from .preproc import IndentationPreprocessor
 from .rate import get_rater
 
 
-class Indentation(object):
-    def __init__(self, idnt_data):
-        """Force-indentation
-
-        Parameters
-        ----------
-        idnt_data: nanite.read.IndentationData
-            Object holding the experimental data
-        """
-        self.metadata = idnt_data.metadata
-        self.path = idnt_data.path
-        self.enum = idnt_data.enum
-
-        #: All data as afmformats.AFMForceDistance
-        self.data = idnt_data
-        #: Default preprocessing steps steps,
+class Indentation(afmformats.AFMForceDistance):
+    def __init__(self, data, metadata, diskcache=None):
+        """Additional functionalities for afmformats.AFMForceDistance"""
+        super(Indentation, self).__init__(data=data,
+                                          metadata=metadata,
+                                          diskcache=diskcache)
+        #: Default preprocessing steps,
         #: see :func:`Indentation.apply_preprocessing`.
         self.preprocessing = []
+        #: Preprocessing options
+        self.preprocessing_options = {}
+        # preprocessing details (for user convenience)
+        self._preprocessing_details = {}
         # protected fit properties
         self._fit_properties = FitProperties()
 
@@ -39,26 +35,16 @@ class Indentation(object):
 
         # Store initial parameters for reset (see `self.reset`)
         frame = inspect.currentframe()
-        args, _, _, values = inspect.getargvalues(frame)
-        self._init_kwargs = {}
-        args.remove("self")
-        for arg in args:
-            self._init_kwargs[arg] = copy.deepcopy(values[arg])
+        iargs, _, _, values = inspect.getargvalues(frame)
+        self._init_kwargs = {
+            "data": copy.deepcopy(data),
+            "metadata": copy.deepcopy(metadata)
+        }
 
-    def __contains__(self, key):
-        return self.data.__contains__(key)
-
-    def __getitem__(self, key):
-        return self.data.__getitem__(key)
-
-    def __setitem__(self, key, value):
-        return self.data.__setitem__(key, value)
-
-    def __repr__(self):
-        return "Indentation {: 6d} in '{}'".format(
-            self.enum,
-            self.path
-        )
+    @property
+    def data(self):
+        warnings.warn("Please use __getitem__ instead!", DeprecationWarning)
+        return self
 
     @property
     def fit_properties(self):
@@ -69,7 +55,8 @@ class Indentation(object):
     def fit_properties(self, fp):
         self._fit_properties.update(fp)
 
-    def apply_preprocessing(self, preprocessing=None):
+    def apply_preprocessing(self, preprocessing=None, options=None,
+                            ret_details=False):
         """Perform curve preprocessing steps
 
         Parameters
@@ -79,32 +66,52 @@ class Indentation(object):
             stored in the `IndentationPreprocessor` class.
             If set to `None`, `self.preprocessing` will be
             used.
+        options: dict of dict
+            Dictionary of keyword arguments for each preprocessing
+            step (if applicable)
+        ret_details:
+            Return preprocessing details dictionary
         """
         if preprocessing is None:
             preprocessing = self.preprocessing
 
+        if options is None:
+            options = self.preprocessing_options
+
         if "preprocessing" in self.fit_properties:
-            preproc_past = self.fit_properties["preprocessing"]
+            preproc_past = [self.fit_properties["preprocessing"],
+                            self.fit_properties["preprocessing_options"]]
+
         else:
             preproc_past = []
 
-        if preproc_past != preprocessing:
+        if ((preproc_past != [preprocessing, options])
+                or (not self._preprocessing_details and ret_details)):
             # Remember initial fit parameters for user convenience
             fp = self.fit_properties
             fp["preprocessing"] = preprocessing
+            fp["preprocessing_options"] = options
             # Reset all data
             self.reset()
             # Apply preprocessing
-            IndentationPreprocessor.apply(self, preprocessing)
+            details = IndentationPreprocessor.apply(apret=self,
+                                                    identifiers=preprocessing,
+                                                    options=options,
+                                                    ret_details=ret_details)
+            self._preprocessing_details = details
             # Check availability of axes
             for ax in ["x_axis", "y_axis"]:
                 # make sure the fitting axes are defined
-                if ax in fp and not fp[ax] in self.data:
+                if ax in fp and not fp[ax] in self:
                     fp.pop(ax)
             # Set new fit properties
             self.fit_properties = fp
+
         # remember preprocessing
         self.preprocessing = preprocessing
+        self.preprocessing_options = copy.deepcopy(options)
+
+        return self._preprocessing_details
 
     def compute_emodulus_mindelta(self, callback=None):
         """Elastic modulus in dependency of maximum indentation
@@ -162,166 +169,15 @@ class Indentation(object):
         )
         return dopt
 
-    @classmethod
-    def _estimate_contact_point_index_from_baseline(cls, fg):
-        idp1 = np.nan
-        # Method 1: base line deviation
-        # Crop the slow approach trace (10% of the curve)
-        baseline = fg[:int(fg.size*.1)]
-        if baseline.size:
-            bl_avg = np.average(baseline)
-            bl_rng = np.max(np.abs(baseline-bl_avg))*2
-            bl_dev = (fg-bl_avg) > bl_rng
-            if np.sum(bl_dev):
-                idp1 = np.where(bl_dev)[0][0]
-        return idp1
+    def estimate_contact_point_index(self, method="deviation_from_baseline"):
+        """Estimate the contact point index
 
-    @classmethod
-    def _estimate_contact_point_index_from_cl_fit(cls, fg):
-        """This is probably the most robust version"""
-        # TODO:
-        # - test whether this is really slower than the other methods
-        def residual(params, x, data):
-            off = params["off"]
-            x0 = params["x0"]
-            m = params["m"]
-            one = off
-            two = m*(x-x0) + off
-            return data - np.maximum(one, two)
-
-        if fg.size > 4:
-            x = np.arange(fg.size)
-
-            params = lmfit.Parameters()
-            params.add('off', value=np.mean(fg[:10]))
-            params.add('x0', value=fg.size//2)
-            params.add('m', value=(fg.max() - fg.min()) / fg.size)
-
-            out = lmfit.minimize(residual, params, args=(x, fg))
-            if out.success:
-                idp = int(out.params["x0"])
-            else:
-                idp = fg.size // 2
-        else:
-            # approach part too short to be reasonable
-            idp = 0
-        return idp
-
-    @classmethod
-    def _estimate_contact_point_index_from_sign_gradient(cls, fg):
-        idp2 = np.nan
-        # Method 2: gradient change
-        # Perform a median filter to smooth the array
-        filtsize = 15
-        y = spsig.medfilt(fg, filtsize)
-        # Cut off the trailing 10 points (noise)
-        cutoff = 10
-        if y.size > cutoff+1:
-            grad = np.gradient(y)[:-cutoff]
-            # Use the point where the gradient becomes positive for the
-            # first time.
-            gradpos = grad > 0
-            if np.sum(gradpos):
-                # The contains positive values.
-                # Flip `gradpos`, because we want the first value from the
-                # end of the array.
-                idp2 = y.size - np.where(gradpos[::-1])[0][0] - cutoff - 1
-        return idp2
-
-    @classmethod
-    def _estimate_contact_point_index_preprocess_gradient(cls, force):
-        # Preprocessing (remove tilt from curve)
-        # apply rolling average filter to force
-        p1_fs = min(47, force.size//2//2*2 + 1)
-        assert p1_fs % 2 == 1, "must be odd"
-        p1_cumsum_vec = np.cumsum(np.insert(np.copy(force), 0, 0))
-        p1 = (p1_cumsum_vec[p1_fs:] - p1_cumsum_vec[:-p1_fs]) / p1_fs
-        # take the gradient
-        if p1.size > 1:
-            p1g = np.gradient(p1)
-            # apply rolling average filter to the gradient
-            p1g_cumsum_vec = np.cumsum(np.insert(np.copy(p1g), 0, 0))
-            p1gm = (p1g_cumsum_vec[p1_fs:] - p1g_cumsum_vec[:-p1_fs]) / p1_fs
-        else:
-            # fallback for bad data (array with very few elements)
-            p1gm = p1
-        return p1gm
-
-    def estimate_contact_point_index(self):
-        """Estimate the contact point
-
-        Contact point (CP) estimation involves a preprocessing step
-        where the force data are transformed into gradient space
-        (to account for a slope in the approach curve) and a
-        subsequent analysis with two different methods to determine
-        when the gradient changes significantly enough to qualify for
-        a CP. Of those two methods, the one which yields the smallest
-        index (measured from the beginning of the approach curve)
-        is returned. If one of the methods fail, then a fit function
-        with a constant and linear part is used to determine the CP.
-
-        Preprocessing:
-
-        1. Compute the rolling average of the force
-           (Otherwise the gradient would be too wild)
-        2. Compute the gradient
-           (Converting to gradient space gets rid of linear
-           contributions in the approach part)
-        3. Compute the rolling average of the gradient
-           (Makes the curve to analyze more smooth so that the
-           methods below don't hit the alarm too early)
-
-        Method 1: baseline deviation
-
-        1. Obtain the baseline (initial 10% of the gradient curve)
-        2. Compute average and maximum deviation of the baseline
-        3. The CP is the index of the curve where it exceeds
-           twice of the maximum deviation
-
-        Method 2: sign of gradient
-
-        1. Apply a median filter to the approach curve
-        2. Compute the gradient
-        3. Cut off trailing 10 points from the gradient (noise)
-        4. The CP is the index of the gradient curve when the
-           sign changes, measured from the point of maximal
-           indentation.
-
-        If one of the methods fail, then a combined constant+linear
-        function (max(constant, linear) is fitted to the gradient to
-        determine the contact point. If that fails as well, then
-        the CP defaults to the center of the entire approach curve.
-
-        .. versionchanged:: 1.6.0
-            Add the gradient preprocessing step to circumvent issues
-            with tilted baselines. This feature does not significantly
-            affect fitting results.
-
-        .. versionchanged:: 1.6.1
-            Added max(constant, linear) fit when the other methods
-            fail.
+        See the `poc` submodule for more information.
         """
-        # get data
-        y0 = np.array(self.data["force"], copy=True)
-        # Only use the (initial) approach part of the curve.
-        idmax = np.argmax(y0)
-        y = y0[:idmax]
-
-        fg = self._estimate_contact_point_index_preprocess_gradient(y)
-        idp1 = self._estimate_contact_point_index_from_baseline(fg)
-        idp2 = self._estimate_contact_point_index_from_sign_gradient(fg)
-
-        if np.isnan(idp1) or np.isnan(idp2):
-            idp = self._estimate_contact_point_index_from_cl_fit(fg)
-        else:
-            idp = min(idp1, idp2)
-
+        idp = poc.compute_poc(force=np.array(self["force"], copy=True),
+                              method=method)
         return idp
 
-    def export(self, path, fmt="tab"):
-        """Saves the current data as tab separated values"""
-        self.data.export(path, fmt=fmt)
-
     def fit_model(self, **kwargs):
         """Fit the approach-retract data to a model function
 
@@ -349,8 +205,10 @@ class Indentation(object):
                 as well, this requires a two-pass fitting.
         preprocessing: list of str
             Preprocessing
+        preprocessing_options: list of str
+            Preprocessing
         segment: str
-            One of "approach" or "retract".
+            Segment index (e.g. 0 for approach)
         weight_cp: float
             Weight the contact point region which shows artifacts
             that are difficult to model with e.g. Hertz.
@@ -360,7 +218,10 @@ class Indentation(object):
             resulting Young's modulus (fitting parameter "E").
         """
         if "preprocessing" in kwargs:
-            self.apply_preprocessing(kwargs["preprocessing"])
+            options = kwargs.get("preprocessing_options",
+                                 self.preprocessing_options)
+            self.apply_preprocessing(preprocessing=kwargs["preprocessing"],
+                                     options=options)
         # self.fit_properties is an instance of FitProperties that
         # stores previous fit kwargs. If the given kwargs are
         # different than in the previous fit, the following two
@@ -480,6 +341,10 @@ class Indentation(object):
         training_set: str
             A label for a training set shipped with nanite or a
             path to a training set.
+        names: list of str
+            Only use these features for rating
+        lda: bool
+            Perform linear discriminant analysis
 
         Returns
         -------
@@ -492,7 +357,7 @@ class Indentation(object):
         The rating is cached based on the fitting hash
         (see `IndentationFitter._hash`).
         """
-        if (self.fit_properties and "hash" in self.fit_properties):
+        if self.fit_properties and "hash" in self.fit_properties:
             curhash = self.fit_properties["hash"]
         else:
             curhash = "none"
