@@ -8,9 +8,9 @@ from nanite import IndentationGroup
 from nanite.fit import FitDataError
 
 
-datapath = pathlib.Path(__file__).parent / "data"
-jpkfile = datapath / "spot3-0192.jpk-force"
-badjpk = datapath / "bad_GWATspot1-data-2017.10.17-16.39.42.396-5.jpk-force"
+data_path = pathlib.Path(__file__).parent / "data"
+jpkfile = data_path / "spot3-0192.jpk-force"
+badjpk = data_path / "bad_GWATspot1-data-2017.10.17-16.39.42.396-5.jpk-force"
 
 
 def test_emodulus_search():
@@ -33,7 +33,7 @@ def test_emodulus_search():
 
     # This assertion might fail when the preprocessing changes
     # or when the search algorithm for the optimal fit changes.
-    dopt = -2.07633035802137e-07
+    dopt = -1.2047321672207138e-07
     assert np.allclose(ar.fit_properties["optimal_fit_delta"], dopt)
 
     if __name__ == "__main__":
