@@ -7,8 +7,8 @@ from nanite import IndentationGroup
 from nanite import model
 
 
-datapath = pathlib.Path(__file__).parent / "data"
-jpkfile = datapath / "spot3-0192.jpk-force"
+data_path = pathlib.Path(__file__).parent / "data"
+jpkfile = data_path / "spot3-0192.jpk-force"
 
 
 def test_changed_fit_properties():
