@@ -6,8 +6,8 @@ import shutil
 from nanite import Indentation, IndentationGroup, load_group
 
 
-datadir = pathlib.Path(__file__).resolve().parent / "data"
-jpkfile = datadir / "spot3-0192.jpk-force"
+data_path = pathlib.Path(__file__).resolve().parent / "data"
+jpkfile = data_path / "spot3-0192.jpk-force"
 
 
 def test_base():
@@ -31,9 +31,9 @@ def test_base():
 
 def test_subgroup():
     tmp = tempfile.mkdtemp(prefix="test_nanite_group")
-    shutil.copy(datadir / "map-data-reference-points.jpk-force-map", tmp)
-    shutil.copy(datadir / "map2x2_extracted.jpk-force-map", tmp)
-    shutil.copy(datadir / "flipsign_2015.05.22-15.31.49.352.jpk-force", tmp)
+    shutil.copy(data_path / "map-data-reference-points.jpk-force-map", tmp)
+    shutil.copy(data_path / "map2x2_extracted.jpk-force-map", tmp)
+    shutil.copy(data_path / "flipsign_2015.05.22-15.31.49.352.jpk-force", tmp)
 
     grp = load_group(tmp)
     exp = pathlib.Path(tmp) / "map2x2_extracted.jpk-force-map"
@@ -42,8 +42,6 @@ def test_subgroup():
     assert len(subgrp) == 4
     assert subgrp[0].path == exp
 
-    shutil.rmtree(tmp, ignore_errors=True)
-
 
 if __name__ == "__main__":
     # Run all tests
