@@ -10,8 +10,8 @@ import nanite
 import nanite.model
 
 
-datapath = pathlib.Path(__file__).parent / "data"
-jpkfile = datapath / "spot3-0192.jpk-force"
+data_path = pathlib.Path(__file__).parent / "data"
+jpkfile = data_path / "spot3-0192.jpk-force"
 
 
 def test_apply_preprocessing():
@@ -68,7 +68,7 @@ def test_basic():
                               "correct_tip_offset"])
     # This value is subject to change if a better way to estimate the
     # contact point is found:
-    assert idnt["tip position"][0] == 4.507445225784438e-06
+    assert idnt["tip position"][0] == 4.765854684370548e-06
 
 
 def test_export():
@@ -78,7 +78,7 @@ def test_export():
     idnt.apply_preprocessing(["compute_tip_position"])
     # create temporary file
     _, path = tempfile.mkstemp(suffix=".tab", prefix="nanite_idnt_export")
-    idnt.export(path)
+    idnt.export_data(path)
     data = afmformats.load_data(path)[0]
     assert len(data) == 4000
     assert np.allclose(data["force"][100], -4.853736717639109e-10)
@@ -90,11 +90,6 @@ def test_export():
                        atol=1e-10, rtol=0)
     assert data["segment"][3000] == 1
 
-    try:
-        pathlib.Path(path).unlink()
-    except OSError:
-        pass
-
 
 def test_fitting():
     ds1 = nanite.IndentationGroup(jpkfile)
@@ -235,6 +230,16 @@ def test_rate_quality_nofit():
     assert r1 == -1
 
 
+def test_repr_str():
+    ds1 = nanite.IndentationGroup(jpkfile)
+    idnt = ds1[0]
+    assert "AFMForceDistance" not in str(idnt)
+    assert "Indentation" in str(idnt)
+    assert "spot3-0192.jpk-force" in str(idnt)
+    assert "Indentation" in repr(idnt)
+    assert "spot3-0192.jpk-force" in repr(idnt)
+
+
 if __name__ == "__main__":
     # Run all tests
     loc = locals()
