@@ -8,8 +8,8 @@ from nanite import IndentationGroup
 from nanite.model import model_hertz_paraboloidal as hertz
 
 
-datadir = pathlib.Path(__file__).resolve().parent / "data"
-jpkfile = datadir / "spot3-0192.jpk-force"
+data_path = pathlib.Path(__file__).resolve().parent / "data"
+jpkfile = data_path / "spot3-0192.jpk-force"
 
 
 def test_app_ret():
@@ -19,7 +19,7 @@ def test_app_ret():
                               "correct_force_offset"])
     idp = idnt.estimate_contact_point_index()
 
-    aprid = ~idnt["segment"]
+    aprid = idnt["segment"] == 0
     x = idnt["tip position"][aprid]
     y = idnt["force"][aprid]
     contact_point = x[idp]
