@@ -4,13 +4,13 @@ import numpy as np
 
 from nanite import IndentationGroup
 
-datadir = pathlib.Path(__file__).resolve().parent / "data"
+data_path = pathlib.Path(__file__).resolve().parent / "data"
 
 
 def test_process_flipsign():
     # This is a curve extracted from a map file. When loading it
     # with nanite, the sign of the force curve was flipped.
-    flipped = datadir / "flipsign_2015.05.22-15.31.49.352.jpk-force"
+    flipped = data_path / "flipsign_2015.05.22-15.31.49.352.jpk-force"
     idnt = IndentationGroup(flipped)[0]
     idnt.apply_preprocessing(["compute_tip_position",
                               "correct_force_offset",
@@ -22,7 +22,7 @@ def test_process_flipsign():
     idnt.fit_model(model_key="hertz_para", weight_cp=False,
                    params_initial=params_initial)
     assert np.allclose(idnt.fit_properties["params_fitted"]["E"].value,
-                       5257.047288859021)
+                       5230.008779761989)
 
 
 if __name__ == "__main__":
