@@ -7,14 +7,14 @@ import numpy as np
 from nanite import model, qmap, IndentationGroup
 
 
-datadir = pathlib.Path(__file__).resolve().parent / "data"
-jpkfile = datadir / "map2x2_extracted.jpk-force-map"
-jpkfile2 = datadir / "map-data-reference-points.jpk-force-map"
+data_path = pathlib.Path(__file__).resolve().parent / "data"
+jpkfile = data_path / "map2x2_extracted.jpk-force-map"
+jpkfile2 = data_path / "map-data-reference-points.jpk-force-map"
 
 
 def test_feat_scan_order():
     qm = qmap.QMap(jpkfile)
-    order = qm.get_qmap("meta scan order", qmap_only=True)
+    order = qm.get_qmap("data: scan order", qmap_only=True)
     assert order[0, 0] == 0
     assert order[0, -1] == 1
     assert order[-1, -1] == 2
@@ -24,7 +24,7 @@ def test_feat_scan_order():
 
 def test_feat_min_height():
     qm = qmap.QMap(jpkfile)
-    qd = qm.get_qmap("data min height", qmap_only=True)
+    qd = qm.get_qmap("data: height base point", qmap_only=True)
     assert np.allclose(qd[0, 0], 40.55030392499141)
     assert np.allclose(qd[0, -1], 47.354988549298945)
     assert np.allclose(qd[-1, -1], 96.1627883099352)
@@ -55,20 +55,20 @@ def test_feat_cp():
                        segment="approach",
                        weight_cp=2e-6)
 
-    qd = qm.get_qmap("fit contact point", qmap_only=True)
+    qd = qm.get_qmap("fit: contact point", qmap_only=True)
     vals = qd.flat[~np.isnan(qd.flat)]
     # These are subject to change when contact point preprocessing
     # changes.
-    assert np.allclose(vals[0], -9.59128590161483e-07), "gray matter"
-    assert np.allclose(vals[2], -3.995012408063929e-06), "white matter"
-    assert np.allclose(vals[1], -9.470884627033841e-07), "background"
+    assert np.allclose(vals[0], -1820.431327293334), "gray matter"
+    assert np.allclose(vals[2], -3581.010097829371), "white matter"
+    assert np.allclose(vals[1], -2106.9835957851064), "background"
 
 
 def test_feat_emod_nofit():
     qm = qmap.QMap(jpkfile)
     with warnings.catch_warnings(record=True) as w:
-        # No data availabale, because there is no fit
-        qd = qm.get_qmap("fit young's modulus", qmap_only=True)
+        # No data available, because there is no fit
+        qd = qm.get_qmap("fit: Young's modulus", qmap_only=True)
         assert len(w) == 4
         assert w[0].category is qmap.DataMissingWarning
     assert np.alltrue(np.isnan(qd))
@@ -98,11 +98,11 @@ def test_feat_emod_withfit():
                        segment="approach",
                        weight_cp=2e-6)
 
-    qd = qm.get_qmap("fit young's modulus", qmap_only=True)
+    qd = qm.get_qmap("fit: Young's modulus", qmap_only=True)
     vals = qd.flat[~np.isnan(qd.flat)]
-    assert np.allclose(vals[0], 57.64803584609825), "gray matter"
-    assert np.allclose(vals[2], 46.607331352457955), "white matter"
-    assert np.allclose(vals[1], 17906.22914200053), "background"
+    assert np.allclose(vals[0], 57.62946472325552), "gray matter"
+    assert np.allclose(vals[2], 46.61406865570242), "white matter"
+    assert np.allclose(vals[1], 17605.034077063443), "background"
 
 
 def test_feat_rating():
@@ -131,9 +131,9 @@ def test_feat_rating():
         idnt.rate_quality(training_set="zef18",
                           regressor="Extra Trees")
 
-    qd = qm.get_qmap("meta rating", qmap_only=True)
+    qd = qm.get_qmap("fit: rating", qmap_only=True)
     vals = qd.flat[~np.isnan(qd.flat)]
-    assert np.allclose(vals[0], 9.353890485442905), "gray matter"
+    assert np.allclose(vals[0], 9.370435813605962), "gray matter"
     assert np.allclose(vals[2], 4.942804081687071), "white matter"
     assert np.allclose(vals[1], 2.432396277782555), "background"
 
@@ -141,8 +141,8 @@ def test_feat_rating():
 def test_feat_rating_nofit():
     qm = qmap.QMap(jpkfile)
     with warnings.catch_warnings(record=True) as w:
-        # No data availabale, because there is no fit
-        qd = qm.get_qmap("meta rating", qmap_only=True)
+        # No data available, because there is no fit
+        qd = qm.get_qmap("fit: rating", qmap_only=True)
         assert len(w) == 4
         assert w[0].category is qmap.DataMissingWarning
     assert np.alltrue(np.isnan(qd))
@@ -175,7 +175,7 @@ def test_get_coords_bad():
 
 def test_get_qmap():
     qm = qmap.QMap(jpkfile)
-    x, y, _ = qm.get_qmap(feature="data min height", qmap_only=False)
+    x, y, _ = qm.get_qmap(feature="data: height base point", qmap_only=False)
     assert x.size == 10
     assert y.size == 10
 
